@@ -114,9 +114,9 @@ def flat_menu(node):
 class MenuIconLoader(object):
     """Load menu icons dynamically."""
     def __init__(self, icon_names):
-        self.icon_names = icon_names
+        self._icon_names = icon_names
     def get(self, name):
-        return gtk.image_new_from_icon_name(self.icon_names[name],
+        return gtk.image_new_from_icon_name(self._icon_names[name],
                                             gtk.ICON_SIZE_MENU)
 
 #----------------------------------------
@@ -165,7 +165,7 @@ def create_menu(udisks=None,
     :param dict labels: Labels for menu items
     :param dict icons: Icons for menu items
     :param dict actions: Actions for menu items
-    :param callabel style: Either of .flat_menu or .simple_menu
+    :param callable style: Either of .flat_menu or .simple_menu
 
     If either ``udisks`` and or ``mounter`` is ``None`` default versions
     will be imported from the udiskie package.
